import { useState, useEffect } from "react";
import env from "../../config/env";

export function formatToList(items) {
  if (!items) {
    return null;
  }

  return (
    <ul style={{ padding: 0 }}>
      {items.map((item) => (
        <li
          style={{ listStylePosition: "inside" }}
          key={item}
        >
          {item}
        </li>
      ))}
    </ul>
  );
}

export function searchInArray(array, searchText) {
  if (array) {
    const found = array.find((element) =>
      element.toLowerCase().includes(searchText)
    );

    return found;
  }

  return false;
}

function getWindowDimensions() {
  const { innerWidth: width, innerHeight: height } = window;
  return {
    width,
    height
  };
}

export function useWindowDimensions() {
  const [windowDimensions, setWindowDimensions] = useState(
    getWindowDimensions()
  );

  useEffect(() => {
    function handleResize() {
      setWindowDimensions(getWindowDimensions());
    }

    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, []);

  return windowDimensions;
}

function applicationSubTitle() {
  const title = `${env.ENVIRONMENT_TITLE}`;

  if (title && title !== "undefined") {
    return " - " + title;
  }

  return "";
}

export function applicationTitle(...breadcrumbs) {
  return [`CE deploy & monitor ${applicationSubTitle()}`, ...breadcrumbs].join(
    " / "
  );
}

export function initRequestParams(lazyParams, filter, columnSort) {
  const requestParams = {
    page: lazyParams.page,
    limit: lazyParams.rows
  };
  if (filter != null && filter) {
    requestParams.query = filter;
  }

  if (columnSort) {
    if (columnSort.sortOrder === 1) {
      requestParams.orderAsc = true;
    } else {
      requestParams.orderAsc = false;
    }
  }

  return requestParams;
}

export const getErrorMessage = (error) => {
  const { response, status: requestStatus, message: requestMessage } = error;
  if (response && response?.body) {
    const {
      body: { description },
      status: httpStatus
    } = response;

    return `${httpStatus ?? requestStatus ?? "unknown"}: ${
      description ?? requestMessage ?? "An unknown error has occurred"
    }`;
  }
  return `${requestStatus}: ${requestMessage}`;
};

export const isAbortError = (error) => error?.name === "AbortError";

export const compareArrays = (a1, a2) =>
  a1.length === a2.length &&
  a1.every((element, index) => element === a2[index]);

export function onFetchEntityError(message, status, setNotFoundError) {
  const notFound = status === 404;
  if (notFound) {
    setNotFoundError(message);
  }
  return !notFound;
}

export function pick(obj, keys) {
  const ret = {};
  for (const key of keys) {
    ret[key] = obj[key];
  }
  return ret;
}
